==> aptechka-0.41.6.tgz: package/lib/css-property/index.js <==
var p = (s) => {
  throw TypeError(s);
};
var S = (s, r, e) => r.has(s) || p("Cannot " + e);
var t = (s, r, e) => (S(s, r, "read from private field"), e ? e.call(s) : r.get(s)), h = (s, r, e) => r.has(s) ? p("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(s) : r.set(s, e), i = (s, r, e, a) => (S(s, r, "write to private field"), a ? a.call(s, e) : r.set(s, e), e);
import { cssValueParser as R } from "../css-value-parser/index.js";
import { RESIZE_ORDER as V } from "../order/index.js";
import { S as g } from "../Store-Cm3LPXlx.js";
import { g as v } from "../dom-0S_WDL4g.js";
import { windowResizer as w } from "../window-resizer/vanilla/index.js";
var b, o, u, l, c, n;
class d extends g {
  constructor(e, a, m, f) {
    super(m, f);
    h(this, b);
    h(this, o);
    h(this, u);
    h(this, l);
    h(this, c, !1);
    h(this, n, () => {
      this.check();
    });
    i(this, b, v(e)), i(this, o, a), i(this, u, m.toString()), i(this, l, (f == null ? void 0 : f.rawValueCheck) !== !1);
  }
  get currentRawValue() {
    return t(this, u);
  }
  observe() {
    t(this, c) || (i(this, c, !0), w.subscribe(t(this, n), V.CSS_VARIABLE));
  }
  unobserve() {
    t(this, c) && (i(this, c, !1), w.unsubscribe(t(this, n)));
  }
  subscribe(e) {
    return this.subscribers.size || this.observe(), super.subscribe(e);
  }
  unsubscribe(e) {
    super.unsubscribe(e), this.subscribers.size || this.unobserve();
  }
  close() {
    this.unobserve(), super.close();
  }
  check() {
    const e = getComputedStyle(t(this, b)).getPropertyValue(t(this, o)).trim();
    if (!(t(this, l) && t(this, u) === e))
      if (i(this, u, e), e) {
        const a = R.parse(t(this, u));
        this.current = a;
      } else
        this.current = this.initial;
  }
}
b = new WeakMap(), o = new WeakMap(), u = new WeakMap(), l = new WeakMap(), c = new WeakMap(), n = new WeakMap();
export {
  d as CSSProperty
};

==> aptechka-0.42.5.tgz: package/lib/css-property/index.js <==
var p = (s) => {
  throw TypeError(s);
};
var S = (s, r, e) => r.has(s) || p("Cannot " + e);
var t = (s, r, e) => (S(s, r, "read from private field"), e ? e.call(s) : r.get(s)), h = (s, r, e) => r.has(s) ? p("Cannot add the same private member more than once") : r instanceof WeakSet ? r.add(s) : r.set(s, e), i = (s, r, e, a) => (S(s, r, "write to private field"), a ? a.call(s, e) : r.set(s, e), e);
import { cssValueParser as R } from "../css-value-parser/index.js";
import { RESIZE_ORDER as V } from "../order/index.js";
import { S as g } from "../Store-Cm3LPXlx.js";
import { g as v } from "../dom-CVWzyXPH.js";
import { windowResizer as w } from "../window-resizer/index.js";
var b, o, u, l, c, n;
class d extends g {
  constructor(e, a, m, f) {
    super(m, f);
    h(this, b);
    h(this, o);
    h(this, u);
    h(this, l);
    h(this, c, !1);
    h(this, n, () => {
      this.check();
    });
    i(this, b, v(e)), i(this, o, a), i(this, u, m.toString()), i(this, l, (f == null ? void 0 : f.rawValueCheck) !== !1);
  }
  get currentRawValue() {
    return t(this, u);
  }
  observe() {
    t(this, c) || (i(this, c, !0), w.subscribe(t(this, n), V.CSS_VARIABLE));
  }
  unobserve() {
    t(this, c) && (i(this, c, !1), w.unsubscribe(t(this, n)));
  }
  subscribe(e) {
    return this.subscribers.size || this.observe(), super.subscribe(e);
  }
  unsubscribe(e) {
    super.unsubscribe(e), this.subscribers.size || this.unobserve();
  }
  close() {
    this.unobserve(), super.close();
  }
  check() {
    const e = getComputedStyle(t(this, b)).getPropertyValue(t(this, o)).trim();
    if (!(t(this, l) && t(this, u) === e))
      if (i(this, u, e), e) {
        const a = R.parse(t(this, u));
        this.current = a;
      } else
        this.current = this.initial;
  }
}
b = new WeakMap(), o = new WeakMap(), u = new WeakMap(), l = new WeakMap(), c = new WeakMap(), n = new WeakMap();
export {
  d as CSSProperty
};
